@@ -11,10 +11,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, Optional
+from typing import Any, Dict, Optional
 
 import torch
 from torch import Tensor
+from typing_extensions import Literal
 
 from torchmetrics.functional.classification.kl_divergence import _kld_compute, _kld_update
 from torchmetrics.metric import Metric
@@ -35,7 +36,7 @@ class KLDivergence(Metric):
         p: data distribution with shape ``[N, d]``
         q: prior or approximate distribution with shape ``[N, d]``
         log_prob: bool indicating if input is log-probabilities or probabilities. If given as probabilities,
-            will normalize to make sure the distributes sum to 1
+            will normalize to make sure the distributes sum to 1.
         reduction:
             Determines how to reduce over the ``N``/batch dimension:
 
@@ -43,11 +44,20 @@ class KLDivergence(Metric):
             - ``'sum'``: Sum score across samples
             - ``'none'`` or ``None``: Returns score per sample
 
+        compute_on_step:
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
+
+
     Raises:
         TypeError:
-            If ``log_prob`` is not an ``bool``
+            If ``log_prob`` is not an ``bool``.
         ValueError:
-            If ``reduction`` is not one of ``'mean'``, ``'sum'``, ``'none'`` or ``None``
+            If ``reduction`` is not one of ``'mean'``, ``'sum'``, ``'none'`` or ``None``.
 
     .. note::
         Half precision is only support on GPU for this metric
@@ -70,18 +80,11 @@ class KLDivergence(Metric):
     def __init__(
         self,
         log_prob: bool = False,
-        reduction: Optional[str] = "mean",
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        reduction: Literal["mean", "sum", "none", None] = "mean",
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         if not isinstance(log_prob, bool):
             raise TypeError(f"Expected argument `log_prob` to be bool but got {log_prob}")
         self.log_prob = log_prob
@@ -92,10 +95,10 @@ class KLDivergence(Metric):
         self.reduction = reduction
 
         if self.reduction in ["mean", "sum"]:
-            self.add_state("measures", torch.zeros(1), dist_reduce_fx="sum")
+            self.add_state("measures", torch.tensor(0.0), dist_reduce_fx="sum")
         else:
             self.add_state("measures", [], dist_reduce_fx="cat")
-        self.add_state("total", torch.zeros(1), dist_reduce_fx="sum")
+        self.add_state("total", torch.tensor(0), dist_reduce_fx="sum")
 
     def update(self, p: Tensor, q: Tensor) -> None:  # type: ignore
         measures, total = _kld_update(p, q, self.log_prob)
