@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import torch
 from torch import Tensor
@@ -39,17 +39,16 @@ class PrecisionRecallCurve(Metric):
     Args:
         num_classes: integer with number of classes for multi-label and multiclass problems.
             Should be set to ``None`` for binary problems
-        pos_label: integer determining the positive class. Default is ``None``
-            which for binary problem is translate to 1. For multiclass problems
-            this argument should not be set as we iteratively change it in the
-            range [0,num_classes-1]
+        pos_label: integer determining the positive class. Default is ``None`` which for binary problem is translated
+            to 1. For multiclass problems this argument should not be set as we iteratively change it in the range
+            ``[0, num_classes-1]``
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example (binary case):
         >>> from torchmetrics import PrecisionRecallCurve
@@ -89,15 +88,10 @@ class PrecisionRecallCurve(Metric):
         self,
         num_classes: Optional[int] = None,
         pos_label: Optional[int] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
 
         self.num_classes = num_classes
         self.pos_label = pos_label
@@ -132,12 +126,12 @@ class PrecisionRecallCurve(Metric):
             3-element tuple containing
 
             precision:
-                tensor where element i is the precision of predictions with
-                score >= thresholds[i] and the last element is 1.
+                tensor where element ``i`` is the precision of predictions with
+                ``score >= thresholds[i]`` and the last element is 1.
                 If multiclass, this is a list of such tensors, one for each class.
             recall:
-                tensor where element i is the recall of predictions with
-                score >= thresholds[i] and the last element is 0.
+                tensor where element ``i`` is the recall of predictions with
+                ``score >= thresholds[i]`` and the last element is 0.
                 If multiclass, this is a list of such tensors, one for each class.
             thresholds:
                 Thresholds used for computing precision/recall scores
