@@ -15,6 +15,7 @@ from typing import Tuple
 
 import torch
 from torch import Tensor
+from typing_extensions import Literal
 
 from torchmetrics.utilities.data import to_categorical
 from torchmetrics.utilities.distributed import reduce
@@ -26,9 +27,8 @@ def _stat_scores(
     class_index: int,
     argmax_dim: int = 1,
 ) -> Tuple[Tensor, Tensor, Tensor, Tensor, Tensor]:
-    """
-    Calculates the number of true positive, false positive, true negative
-    and false negative for a specific class
+    """Calculates the number of true positive, false positive, true negative and false negative for a specific
+    class.
 
     Args:
         preds: prediction tensor
@@ -46,7 +46,6 @@ def _stat_scores(
         >>> tp, fp, tn, fn, sup = _stat_scores(x, y, class_index=1)
         >>> tp, fp, tn, fn, sup
         (tensor(0), tensor(1), tensor(2), tensor(0), tensor(0))
-
     """
     if preds.ndim == target.ndim + 1:
         preds = to_categorical(preds, argmax_dim=argmax_dim)
@@ -66,10 +65,9 @@ def dice_score(
     bg: bool = False,
     nan_score: float = 0.0,
     no_fg_score: float = 0.0,
-    reduction: str = 'elementwise_mean',
+    reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
 ) -> Tensor:
-    """
-    Compute dice score from prediction scores
+    """Compute dice score from prediction scores.
 
     Args:
         preds: estimated probabilities
@@ -81,7 +79,7 @@ def dice_score(
 
             - ``'elementwise_mean'``: takes the mean (default)
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
     Return:
         Tensor containing dice score
@@ -95,10 +93,9 @@ def dice_score(
         >>> target = torch.tensor([0, 1, 3, 2])
         >>> dice_score(pred, target)
         tensor(0.3333)
-
     """
     num_classes = preds.shape[1]
-    bg_inv = (1 - int(bg))
+    bg_inv = 1 - int(bg)
     scores = torch.zeros(num_classes - bg_inv, device=preds.device, dtype=torch.float32)
     for i in range(bg_inv, num_classes):
         if not (target == i).any():
