@@ -14,62 +14,15 @@
 from typing import List, Optional, Sequence, Tuple, Union
 
 import torch
-from deprecate import deprecated, void
 from torch import Tensor
 from torch.nn import functional as F
 from typing_extensions import Literal
 
-from torchmetrics.utilities import _future_warning
+from torchmetrics.functional.image.helper import _gaussian_kernel_2d, _gaussian_kernel_3d, _reflection_pad_3d
 from torchmetrics.utilities.checks import _check_same_shape
 from torchmetrics.utilities.distributed import reduce
 
 
-def _gaussian(kernel_size: int, sigma: float, dtype: torch.dtype, device: torch.device) -> Tensor:
-    """Computes 1D gaussian kernel.
-
-    Args:
-        kernel_size: size of the gaussian kernel
-        sigma: Standard deviation of the gaussian kernel
-        dtype: data type of the output tensor
-        device: device of the output tensor
-
-    Example:
-        >>> _gaussian(3, 1, torch.float, 'cpu')
-        tensor([[0.2741, 0.4519, 0.2741]])
-    """
-    dist = torch.arange(start=(1 - kernel_size) / 2, end=(1 + kernel_size) / 2, step=1, dtype=dtype, device=device)
-    gauss = torch.exp(-torch.pow(dist / sigma, 2) / 2)
-    return (gauss / gauss.sum()).unsqueeze(dim=0)  # (1, kernel_size)
-
-
-def _gaussian_kernel(
-    channel: int, kernel_size: Sequence[int], sigma: Sequence[float], dtype: torch.dtype, device: torch.device
-) -> Tensor:
-    """Computes 2D gaussian kernel.
-
-    Args:
-        channel: number of channels in the image
-        kernel_size: size of the gaussian kernel as a tuple (h, w)
-        sigma: Standard deviation of the gaussian kernel
-        dtype: data type of the output tensor
-        device: device of the output tensor
-
-    Example:
-        >>> _gaussian_kernel(1, (5,5), (1,1), torch.float, "cpu")
-        tensor([[[[0.0030, 0.0133, 0.0219, 0.0133, 0.0030],
-                  [0.0133, 0.0596, 0.0983, 0.0596, 0.0133],
-                  [0.0219, 0.0983, 0.1621, 0.0983, 0.0219],
-                  [0.0133, 0.0596, 0.0983, 0.0596, 0.0133],
-                  [0.0030, 0.0133, 0.0219, 0.0133, 0.0030]]]])
-    """
-
-    gaussian_kernel_x = _gaussian(kernel_size[0], sigma[0], dtype, device)
-    gaussian_kernel_y = _gaussian(kernel_size[1], sigma[1], dtype, device)
-    kernel = torch.matmul(gaussian_kernel_x.t(), gaussian_kernel_y)  # (kernel_size, 1) * (1, kernel_size)
-
-    return kernel.expand(channel, 1, kernel_size[0], kernel_size[1])
-
-
 def _ssim_update(preds: Tensor, target: Tensor) -> Tuple[Tensor, Tensor]:
     """Updates and returns variables required to compute Structural Similarity Index Measure. Checks for same shape
     and type of the input tensors.
@@ -85,9 +38,9 @@ def _ssim_update(preds: Tensor, target: Tensor) -> Tuple[Tensor, Tensor]:
             f" Got preds: {preds.dtype} and target: {target.dtype}."
         )
     _check_same_shape(preds, target)
-    if len(preds.shape) != 4:
+    if len(preds.shape) not in (4, 5):
         raise ValueError(
-            "Expected `preds` and `target` to have BxCxHxW shape."
+            "Expected `preds` and `target` to have BxCxHxW or BxCxDxHxW shape."
             f" Got preds: {preds.shape} and target: {target.shape}."
         )
     return preds, target
@@ -96,12 +49,14 @@ def _ssim_update(preds: Tensor, target: Tensor) -> Tuple[Tensor, Tensor]:
 def _ssim_compute(
     preds: Tensor,
     target: Tensor,
-    kernel_size: Sequence[int] = (11, 11),
-    sigma: Sequence[float] = (1.5, 1.5),
-    reduction: str = "elementwise_mean",
+    gaussian_kernel: bool = True,
+    sigma: Union[float, Sequence[float]] = 1.5,
+    kernel_size: Union[int, Sequence[int]] = 11,
+    reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
     data_range: Optional[float] = None,
     k1: float = 0.01,
     k2: float = 0.03,
+    return_full_image: bool = False,
     return_contrast_sensitivity: bool = False,
 ) -> Union[Tensor, Tuple[Tensor, Tensor]]:
     """Computes Structual Similarity Index Measure.
@@ -109,17 +64,25 @@ def _ssim_compute(
     Args:
         preds: estimated image
         target: ground truth image
-        kernel_size: size of the gaussian kernel (default: (11, 11))
-        sigma: Standard deviation of the gaussian kernel (default: (1.5, 1.5))
+        gaussian_kernel: If true (default), a gaussian kernel is used, if false a uniform kernel is used
+        sigma: Standard deviation of the gaussian kernel, anisotropic kernels are possible.
+            Ignored if a uniform kernel is used
+        kernel_size: the size of the uniform kernel, anisotropic kernels are possible.
+            Ignored if a Gaussian kernel is used
         reduction: a method to reduce metric score over labels.
 
-            - ``'elementwise_mean'``: takes the mean (default)
+            - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         data_range: Range of the image. If ``None``, it is determined from the image (max - min)
         k1: Parameter of SSIM.
         k2: Parameter of SSIM.
+        return_full_image: If true, the full ``ssim`` image is returned as a second argument.
+            Mutually exlusive with ``return_contrast_sensitivity``
+        return_contrast_sensitivity: If true, the contrast term is returned as a second argument.
+            The luminance term can be obtained with luminance=ssim/contrast
+            Mutually exclusive with ``return_full_image``
 
     Example:
         >>> preds = torch.rand([16, 1, 16, 16])
@@ -128,10 +91,30 @@ def _ssim_compute(
         >>> _ssim_compute(preds, target)
         tensor(0.9219)
     """
-    if len(kernel_size) != 2 or len(sigma) != 2:
+    is_3d = len(preds.shape) == 5
+
+    if not isinstance(kernel_size, Sequence):
+        kernel_size = 3 * [kernel_size] if is_3d else 2 * [kernel_size]
+    if not isinstance(sigma, Sequence):
+        sigma = 3 * [sigma] if is_3d else 2 * [sigma]
+
+    if len(kernel_size) != len(target.shape) - 2:
         raise ValueError(
-            "Expected `kernel_size` and `sigma` to have the length of two."
-            f" Got kernel_size: {len(kernel_size)} and sigma: {len(sigma)}."
+            f"`kernel_size` has dimension {len(kernel_size)}, but expected to be two less that target dimensionality,"
+            f" which is: {len(target.shape)}"
+        )
+    if len(kernel_size) not in (2, 3):
+        raise ValueError(
+            f"Expected `kernel_size` dimension to be 2 or 3. `kernel_size` dimensionality: {len(kernel_size)}"
+        )
+    if len(sigma) != len(target.shape) - 2:
+        raise ValueError(
+            f"`kernel_size` has dimension {len(kernel_size)}, but expected to be two less that target dimensionality,"
+            f" which is: {len(target.shape)}"
+        )
+    if len(sigma) not in (2, 3):
+        raise ValueError(
+            f"Expected `kernel_size` dimension to be 2 or 3. `kernel_size` dimensionality: {len(kernel_size)}"
         )
 
     if any(x % 2 == 0 or x <= 0 for x in kernel_size):
@@ -149,15 +132,33 @@ def _ssim_compute(
 
     channel = preds.size(1)
     dtype = preds.dtype
-    kernel = _gaussian_kernel(channel, kernel_size, sigma, dtype, device)
-    pad_h = (kernel_size[0] - 1) // 2
-    pad_w = (kernel_size[1] - 1) // 2
+    gauss_kernel_size = [int(3.5 * s + 0.5) * 2 + 1 for s in sigma]
 
-    preds = F.pad(preds, (pad_h, pad_h, pad_w, pad_w), mode="reflect")
-    target = F.pad(target, (pad_h, pad_h, pad_w, pad_w), mode="reflect")
+    pad_h = (gauss_kernel_size[0] - 1) // 2
+    pad_w = (gauss_kernel_size[1] - 1) // 2
+
+    if is_3d:
+        pad_d = (gauss_kernel_size[2] - 1) // 2
+        preds = _reflection_pad_3d(preds, pad_d, pad_w, pad_h)
+        target = _reflection_pad_3d(target, pad_d, pad_w, pad_h)
+        if gaussian_kernel:
+            kernel = _gaussian_kernel_3d(channel, gauss_kernel_size, sigma, dtype, device)
+    else:
+        preds = F.pad(preds, (pad_w, pad_w, pad_h, pad_h), mode="reflect")
+        target = F.pad(target, (pad_w, pad_w, pad_h, pad_h), mode="reflect")
+        if gaussian_kernel:
+            kernel = _gaussian_kernel_2d(channel, gauss_kernel_size, sigma, dtype, device)
+
+    if not gaussian_kernel:
+        kernel = torch.ones((1, 1, *kernel_size)) / torch.prod(torch.Tensor(kernel_size))
 
     input_list = torch.cat((preds, target, preds * preds, target * target, preds * target))  # (5 * B, C, H, W)
-    outputs = F.conv2d(input_list, kernel, groups=channel)
+
+    if is_3d:
+        outputs = F.conv3d(input_list, kernel, groups=channel)
+    else:
+        outputs = F.conv2d(input_list, kernel, groups=channel)
+
     output_list = outputs.split(preds.shape[0])
 
     mu_pred_sq = output_list[0].pow(2)
@@ -171,43 +172,65 @@ def _ssim_compute(
     upper = 2 * sigma_pred_target + c2
     lower = sigma_pred_sq + sigma_target_sq + c2
 
-    ssim_idx = ((2 * mu_pred_target + c1) * upper) / ((mu_pred_sq + mu_target_sq + c1) * lower)
-    ssim_idx = ssim_idx[..., pad_h:-pad_h, pad_w:-pad_w]
+    ssim_idx_full_image = ((2 * mu_pred_target + c1) * upper) / ((mu_pred_sq + mu_target_sq + c1) * lower)
+
+    if is_3d:
+        ssim_idx = ssim_idx_full_image[..., pad_h:-pad_h, pad_w:-pad_w, pad_d:-pad_d]
+    else:
+        ssim_idx = ssim_idx_full_image[..., pad_h:-pad_h, pad_w:-pad_w]
 
     if return_contrast_sensitivity:
         contrast_sensitivity = upper / lower
         contrast_sensitivity = contrast_sensitivity[..., pad_h:-pad_h, pad_w:-pad_w]
-        return reduce(ssim_idx, reduction), reduce(contrast_sensitivity, reduction)
+        return reduce(ssim_idx.reshape(ssim_idx.shape[0], -1).mean(-1), reduction), reduce(
+            contrast_sensitivity.reshape(contrast_sensitivity.shape[0], -1).mean(-1), reduction
+        )
 
-    return reduce(ssim_idx, reduction)
+    elif return_full_image:
+        return reduce(ssim_idx.reshape(ssim_idx.shape[0], -1).mean(-1), reduction), reduce(
+            ssim_idx_full_image, reduction
+        )
+
+    return reduce(ssim_idx.reshape(ssim_idx.shape[0], -1).mean(-1), reduction)
 
 
 def structural_similarity_index_measure(
     preds: Tensor,
     target: Tensor,
-    kernel_size: Sequence[int] = (11, 11),
-    sigma: Sequence[float] = (1.5, 1.5),
-    reduction: str = "elementwise_mean",
+    gaussian_kernel: bool = True,
+    sigma: Union[float, Sequence[float]] = 1.5,
+    kernel_size: Union[int, Sequence[int]] = 11,
+    reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
     data_range: Optional[float] = None,
     k1: float = 0.01,
     k2: float = 0.03,
-) -> Tensor:
-    """Computes Structural Similarity Index Measure.
+    return_full_image: bool = False,
+    return_contrast_sensitivity: bool = False,
+) -> Union[Tensor, Tuple[Tensor, Tensor]]:
+    """Computes Structual Similarity Index Measure.
 
     Args:
         preds: estimated image
         target: ground truth image
-        kernel_size: size of the gaussian kernel (default: (11, 11))
-        sigma: Standard deviation of the gaussian kernel (default: (1.5, 1.5))
+        gaussian_kernel: If true (default), a gaussian kernel is used, if false a uniform kernel is used
+        sigma: Standard deviation of the gaussian kernel, anisotropic kernels are possible.
+            Ignored if a uniform kernel is used
+        kernel_size: the size of the uniform kernel, anisotropic kernels are possible.
+            Ignored if a Gaussian kernel is used
         reduction: a method to reduce metric score over labels.
 
-            - ``'elementwise_mean'``: takes the mean (default)
+            - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         data_range: Range of the image. If ``None``, it is determined from the image (max - min)
         k1: Parameter of SSIM.
         k2: Parameter of SSIM.
+        return_full_image: If true, the full ``ssim`` image is returned as a second argument.
+            Mutually exclusive with ``return_contrast_sensitivity``
+        return_contrast_sensitivity: If true, the constant term is returned as a second argument.
+            The luminance term can be obtained with luminance=ssim/contrast
+            Mutually exclusive with ``return_full_image``
 
     Return:
         Tensor with SSIM score
@@ -232,47 +255,44 @@ def structural_similarity_index_measure(
         tensor(0.9219)
     """
     preds, target = _ssim_update(preds, target)
-    return _ssim_compute(preds, target, kernel_size, sigma, reduction, data_range, k1, k2)
-
-
-@deprecated(target=structural_similarity_index_measure, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-def ssim(
-    preds: Tensor,
-    target: Tensor,
-    kernel_size: Sequence[int] = (11, 11),
-    sigma: Sequence[float] = (1.5, 1.5),
-    reduction: str = "elementwise_mean",
-    data_range: Optional[float] = None,
-    k1: float = 0.01,
-    k2: float = 0.03,
-) -> Tensor:
-    """Computes Structural Similarity Index Measure.
-
-    .. deprecated:: v0.7
-        Use :func:`torchmetrics.functional.scale_invariant_signal_noise_ratio`. Will be removed in v0.8.
-
-    Example:
-        >>> preds = torch.rand([16, 1, 16, 16])
-        >>> target = preds * 0.75
-        >>> ssim(preds, target)
-        tensor(0.9219)
-    """
-    return void(preds, target, kernel_size, sigma, reduction, data_range, k1, k2)
+    return _ssim_compute(
+        preds,
+        target,
+        gaussian_kernel,
+        sigma,
+        kernel_size,
+        reduction,
+        data_range,
+        k1,
+        k2,
+        return_full_image,
+        return_contrast_sensitivity,
+    )
 
 
 def _get_normalized_sim_and_cs(
     preds: Tensor,
     target: Tensor,
-    kernel_size: Sequence[int] = (11, 11),
-    sigma: Sequence[float] = (1.5, 1.5),
-    reduction: str = "elementwise_mean",
+    gaussian_kernel: bool = True,
+    sigma: Union[float, Sequence[float]] = 1.5,
+    kernel_size: Union[int, Sequence[int]] = 11,
+    reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
     data_range: Optional[float] = None,
     k1: float = 0.01,
     k2: float = 0.03,
     normalize: Optional[Literal["relu", "simple"]] = None,
 ) -> Tuple[Tensor, Tensor]:
     sim, contrast_sensitivity = _ssim_compute(
-        preds, target, kernel_size, sigma, reduction, data_range, k1, k2, return_contrast_sensitivity=True
+        preds,
+        target,
+        gaussian_kernel,
+        sigma,
+        kernel_size,
+        reduction,
+        data_range,
+        k1,
+        k2,
+        return_contrast_sensitivity=True,
     )
     if normalize == "relu":
         sim = torch.relu(sim)
@@ -283,9 +303,10 @@ def _get_normalized_sim_and_cs(
 def _multiscale_ssim_compute(
     preds: Tensor,
     target: Tensor,
-    kernel_size: Sequence[int] = (11, 11),
-    sigma: Sequence[float] = (1.5, 1.5),
-    reduction: str = "elementwise_mean",
+    gaussian_kernel: bool = True,
+    sigma: Union[float, Sequence[float]] = 1.5,
+    kernel_size: Union[int, Sequence[int]] = 11,
+    reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
     data_range: Optional[float] = None,
     k1: float = 0.01,
     k2: float = 0.03,
@@ -298,24 +319,25 @@ def _multiscale_ssim_compute(
     ),
     normalize: Optional[Literal["relu", "simple"]] = None,
 ) -> Tensor:
-    """Computes Multi-Scale Structual Similarity Index Measure. Adapted from: https://github.com/jorge-
-    pessoa/pytorch-msssim/blob/master/pytorch_msssim/__init__.py.
+    """Computes Multi-Scale Structual Similarity Index Measure.
+
+    Adapted from: https://github.com/jorge-pessoa/pytorch-msssim/blob/master/pytorch_msssim/__init__.py.
 
     Args:
         preds: estimated image
         target: ground truth image
-        kernel_size: size of the gaussian kernel (default: (11, 11))
-        sigma: Standard deviation of the gaussian kernel (default: (1.5, 1.5))
+        kernel_size: size of the gaussian kernel
+        sigma: Standard deviation of the gaussian kernel
         reduction: a method to reduce metric score over labels.
 
-            - ``'elementwise_mean'``: takes the mean (default)
+            - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         data_range: Range of the image. If ``None``, it is determined from the image (max - min)
         k1: Parameter of structural similarity index measure.
         k2: Parameter of structural similarity index measure.
-        betas: Exponent parameters for individual similarities and contrastive sensitivies returned by different image
+        betas: Exponent parameters for individual similarities and contrastive sensitives returned by different image
             resolutions.
         normalize: When MultiScaleSSIM loss is used for training, it is desirable to use normalizes to improve the
             training stability. This `normalize` argument is out of scope of the original implementation [1], and it is
@@ -332,6 +354,13 @@ def _multiscale_ssim_compute(
     sim_list: List[Tensor] = []
     cs_list: List[Tensor] = []
 
+    is_3d = len(preds.shape) == 5
+
+    if not isinstance(kernel_size, Sequence):
+        kernel_size = 3 * [kernel_size] if is_3d else 2 * [kernel_size]
+    if not isinstance(sigma, Sequence):
+        sigma = 3 * [sigma] if is_3d else 2 * [sigma]
+
     if preds.size()[-1] < 2 ** len(betas) or preds.size()[-2] < 2 ** len(betas):
         raise ValueError(
             f"For a given number of `betas` parameters {len(betas)}, the image height and width dimensions must be"
@@ -352,13 +381,18 @@ def _multiscale_ssim_compute(
 
     for _ in range(len(betas)):
         sim, contrast_sensitivity = _get_normalized_sim_and_cs(
-            preds, target, kernel_size, sigma, reduction, data_range, k1, k2, normalize
+            preds, target, gaussian_kernel, sigma, kernel_size, reduction, data_range, k1, k2, normalize=normalize
         )
         sim_list.append(sim)
         cs_list.append(contrast_sensitivity)
-        preds = F.avg_pool2d(preds, (2, 2))
-        target = F.avg_pool2d(target, (2, 2))
-
+        if len(kernel_size) == 2:
+            preds = F.avg_pool2d(preds, (2, 2))
+            target = F.avg_pool2d(target, (2, 2))
+        elif len(kernel_size) == 3:
+            preds = F.avg_pool3d(preds, (2, 2, 2))
+            target = F.avg_pool3d(target, (2, 2, 2))
+        else:
+            raise ValueError("length of kernel_size is neither 2 nor 3")
     sim_stack = torch.stack(sim_list)
     cs_stack = torch.stack(cs_list)
 
@@ -366,17 +400,25 @@ def _multiscale_ssim_compute(
         sim_stack = (sim_stack + 1) / 2
         cs_stack = (cs_stack + 1) / 2
 
-    sim_stack = sim_stack ** torch.tensor(betas, device=sim_stack.device)
-    cs_stack = cs_stack ** torch.tensor(betas, device=cs_stack.device)
-    return torch.prod(cs_stack[:-1]) * sim_stack[-1]
+    if reduction is None or reduction == "none":
+        betas = torch.tensor(betas).unsqueeze(1).repeat(1, sim_stack.shape[0])
+        sim_stack = sim_stack ** torch.tensor(betas, device=sim_stack.device)
+        cs_stack = cs_stack ** torch.tensor(betas, device=cs_stack.device)
+        cs_and_sim = torch.cat((cs_stack[:-1], sim_stack[-1:]), axis=0)
+        return torch.prod(cs_and_sim, axis=0)
+    else:
+        sim_stack = sim_stack ** torch.tensor(betas, device=sim_stack.device)
+        cs_stack = cs_stack ** torch.tensor(betas, device=cs_stack.device)
+        return torch.prod(cs_stack[:-1]) * sim_stack[-1]
 
 
 def multiscale_structural_similarity_index_measure(
     preds: Tensor,
     target: Tensor,
-    kernel_size: Sequence[int] = (11, 11),
-    sigma: Sequence[float] = (1.5, 1.5),
-    reduction: str = "elementwise_mean",
+    gaussian_kernel: bool = True,
+    sigma: Union[float, Sequence[float]] = 1.5,
+    kernel_size: Union[int, Sequence[int]] = 11,
+    reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
     data_range: Optional[float] = None,
     k1: float = 0.01,
     k2: float = 0.03,
@@ -387,15 +429,15 @@ def multiscale_structural_similarity_index_measure(
     Structual Similarity Index Measure by incorporating image details at different resolution scores.
 
     Args:
-        preds: Predictions from model of shape `[N, C, H, W]`
-        target: Ground truth values of shape `[N, C, H, W]`
-        kernel_size: size of the gaussian kernel (default: (11, 11))
-        sigma: Standard deviation of the gaussian kernel (default: (1.5, 1.5))
+        preds: Predictions from model of shape ``[N, C, H, W]``
+        target: Ground truth values of shape ``[N, C, H, W]``
+        kernel_size: size of the gaussian kernel
+        sigma: Standard deviation of the gaussian kernel
         reduction: a method to reduce metric score over labels.
 
-            - ``'elementwise_mean'``: takes the mean (default)
+            - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         data_range: Range of the image. If ``None``, it is determined from the image (max - min)
         k1: Parameter of structural similarity index measure.
@@ -429,8 +471,8 @@ def multiscale_structural_similarity_index_measure(
         tensor(0.9558)
 
     References:
-    [1] Multi-Scale Structural Similarity For Image Quality Assessment by Zhou Wang, Eero P. Simoncelli and Alan C.
-    Bovik `MultiScaleSSIM`_
+        [1] Multi-Scale Structural Similarity For Image Quality Assessment by Zhou Wang, Eero P. Simoncelli and Alan C.
+        Bovik `MultiScaleSSIM`_
     """
     if not isinstance(betas, tuple):
         raise ValueError("Argument `betas` is expected to be of a type tuple.")
@@ -440,4 +482,6 @@ def multiscale_structural_similarity_index_measure(
         raise ValueError("Argument `normalize` to be expected either `None` or one of 'relu' or 'simple'")
 
     preds, target = _ssim_update(preds, target)
-    return _multiscale_ssim_compute(preds, target, kernel_size, sigma, reduction, data_range, k1, k2, betas, normalize)
+    return _multiscale_ssim_compute(
+        preds, target, gaussian_kernel, sigma, kernel_size, reduction, data_range, k1, k2, betas, normalize
+    )
