@@ -27,8 +27,9 @@ def xlogy(x: Tensor, y: Tensor) -> Tensor:
 
 
 def _tweedie_deviance_score_update(preds: Tensor, targets: Tensor, power: float = 0.0) -> Tuple[Tensor, Tensor]:
-    """Updates and returns variables required to compute Deviance Score for the given power. Checks for same shape
-    of input tensors.
+    """Updates and returns variables required to compute Deviance Score for the given power.
+
+    Checks for same shape of input tensors.
 
     Args:
         preds: Predicted tensor
@@ -107,8 +108,7 @@ def _tweedie_deviance_score_compute(sum_deviance_score: Tensor, num_observations
 
 
 def tweedie_deviance_score(preds: Tensor, targets: Tensor, power: float = 0.0) -> Tensor:
-    r"""
-    Computes the `Tweedie Deviance Score`_ between targets and predictions:
+    r"""Computes the `Tweedie Deviance Score`_ between targets and predictions:
 
     .. math::
         deviance\_score(\hat{y},y) =
@@ -126,13 +126,13 @@ def tweedie_deviance_score(preds: Tensor, targets: Tensor, power: float = 0.0) -
         preds: Predicted tensor with shape ``(N,...)``
         targets: Ground truth tensor with shape ``(N,...)``
         power:
-            - power < 0 : Extreme stable distribution. (Requires: preds > 0.)
-            - power = 0 : Normal distribution. (Requires: targets and preds can be any real numbers.)
-            - power = 1 : Poisson distribution. (Requires: targets >= 0 and y_pred > 0.)
-            - 1 < p < 2 : Compound Poisson distribution. (Requires: targets >= 0 and preds > 0.)
-            - power = 2 : Gamma distribution. (Requires: targets > 0 and preds > 0.)
-            - power = 3 : Inverse Gaussian distribution. (Requires: targets > 0 and preds > 0.)
-            - otherwise : Positive stable distribution. (Requires: targets > 0 and preds > 0.)
+            - `power < 0` : Extreme stable distribution. (Requires: preds > 0.)
+            - `power = 0` : Normal distribution. (Requires: targets and preds can be any real numbers.)
+            - `power = 1` : Poisson distribution. (Requires: targets >= 0 and y_pred > 0.)
+            - `1 < p < 2` : Compound Poisson distribution. (Requires: targets >= 0 and preds > 0.)
+            - `power = 2` : Gamma distribution. (Requires: targets > 0 and preds > 0.)
+            - `power = 3` : Inverse Gaussian distribution. (Requires: targets > 0 and preds > 0.)
+            - `otherwise` : Positive stable distribution. (Requires: targets > 0 and preds > 0.)
 
     Example:
         >>> from torchmetrics.functional import tweedie_deviance_score
