@@ -18,14 +18,10 @@
 # Link: https://pytorch.org/text/_modules/torchtext/data/metrics.html#bleu_score
 from collections import Counter
 from typing import Callable, Sequence, Tuple, Union
-from warnings import warn
 
 import torch
-from deprecate import deprecated
 from torch import Tensor, tensor
 
-from torchmetrics.utilities import _future_warning
-
 
 def _count_ngram(ngram_input_list: Sequence[str], n_gram: int) -> Counter:
     """Counting how many times each word appears in a given text with ngram.
@@ -123,7 +119,7 @@ def _bleu_score_compute(
         numerator: Numerator of precision score (true positives)
         denominator: Denominator of precision score (true positives + false positives)
         n_gram: gram value ranged 1 to 4
-        smooth: Whether or not to apply smoothing
+        smooth: Whether to apply smoothing
     """
     device = numerator.device
     if min(numerator) == 0.0:
@@ -146,13 +142,6 @@ def _bleu_score_compute(
     return bleu
 
 
-@deprecated(
-    args_mapping={"translate_corpus": "preds", "reference_corpus": "target"},
-    target=True,
-    deprecated_in="0.7",
-    remove_in="0.8",
-    stream=_future_warning,
-)
 def bleu_score(
     preds: Union[str, Sequence[str]],
     target: Sequence[Union[str, Sequence[str]]],
@@ -162,25 +151,14 @@ def bleu_score(
     """Calculate `BLEU score`_ of machine translated text with one or more references.
 
     Args:
-        preds:
-            An iterable of machine translated corpus
-        target:
-            An iterable of iterables of reference corpus
-        n_gram:
-            Gram value ranged from 1 to 4 (Default 4)
-        smooth:
-            Whether or not to apply smoothing – see [2]
+        preds: An iterable of machine translated corpus
+        target: An iterable of iterables of reference corpus
+        n_gram: Gram value ranged from 1 to 4 (Default 4)
+        smooth: Whether to apply smoothing – see [2]
 
     Return:
         Tensor with BLEU Score
 
-    .. deprecated:: v0.7
-        Args:
-            translate_corpus:
-                This argument is deprecated in favor of  `preds` and will be removed in v0.8.
-            reference_corpus:
-                This argument is deprecated in favor of  `target` and will be removed in v0.8.
-
     Example:
         >>> from torchmetrics.functional import bleu_score
         >>> preds = ['the cat is on the mat']
@@ -195,11 +173,6 @@ def bleu_score(
         [2] Automatic Evaluation of Machine Translation Quality Using Longest Common Subsequence
         and Skip-Bigram Statistics by Chin-Yew Lin and Franz Josef Och `Machine Translation Evolution`_
     """
-    warn(
-        "Input order of targets and preds were changed to predictions firsts and targets second in v0.7."
-        " Warning will be removed in v0.8."
-    )
-
     preds_ = [preds] if isinstance(preds, str) else preds
     target_ = [[tgt] if isinstance(tgt, str) else tgt for tgt in target]
 
