@@ -11,15 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, Optional, Sequence, Tuple, Union
 
 import torch
-from deprecate import deprecated, void
 from torch import Tensor, tensor
+from typing_extensions import Literal
 
 from torchmetrics.functional.image.psnr import _psnr_compute, _psnr_update
 from torchmetrics.metric import Metric
-from torchmetrics.utilities import _future_warning, rank_zero_warn
+from torchmetrics.utilities import rank_zero_warn
 
 
 class PeakSignalNoiseRatio(Metric):
@@ -39,18 +39,18 @@ class PeakSignalNoiseRatio(Metric):
 
             - ``'elementwise_mean'``: takes the mean (default)
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         dim:
             Dimensions to reduce PSNR scores over, provided as either an integer or a list of integers. Default is
             None meaning scores will be reduced across all dimensions and all batches.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
@@ -70,23 +70,18 @@ class PeakSignalNoiseRatio(Metric):
     """
     min_target: Tensor
     max_target: Tensor
-    higher_is_better = False
+    higher_is_better = True
 
     def __init__(
         self,
         data_range: Optional[float] = None,
         base: float = 10.0,
-        reduction: str = "elementwise_mean",
+        reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
         dim: Optional[Union[int, Tuple[int, ...]]] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
 
         if dim is None and reduction != "elementwise_mean":
             rank_zero_warn(f"The `reduction={reduction}` will not have any effect when `dim` is None.")
@@ -147,29 +142,3 @@ class PeakSignalNoiseRatio(Metric):
             sum_squared_error = torch.cat([values.flatten() for values in self.sum_squared_error])
             total = torch.cat([values.flatten() for values in self.total])
         return _psnr_compute(sum_squared_error, total, data_range, base=self.base, reduction=self.reduction)
-
-
-class PSNR(PeakSignalNoiseRatio):
-    """Peak Signal Noise Ratio (PSNR).
-
-    .. deprecated:: v0.7
-        Use :class:`torchmetrics.PeakSignalNoiseRatio`. Will be removed in v0.8.
-
-    Example:
-        >>> psnr = PSNR()
-        >>> psnr(torch.tensor([[0.0, 1.0], [2.0, 3.0]]), torch.tensor([[3.0, 2.0], [1.0, 0.0]]))
-        tensor(2.5527)
-    """
-
-    @deprecated(target=PeakSignalNoiseRatio, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-    def __init__(
-        self,
-        data_range: Optional[float] = None,
-        base: float = 10.0,
-        reduction: str = "elementwise_mean",
-        dim: Optional[Union[int, Tuple[int, ...]]] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-    ) -> None:
-        void(data_range, base, reduction, dim, compute_on_step, dist_sync_on_step, process_group)
