@@ -11,10 +11,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, List, Optional
+from typing import Any, Dict, List, Optional
 
 import torch
 from torch import Tensor
+from typing_extensions import Literal
 
 from torchmetrics.functional.regression.cosine_similarity import _cosine_similarity_compute, _cosine_similarity_update
 from torchmetrics.metric import Metric
@@ -38,19 +39,14 @@ class CosineSimilarity(Metric):
     - ``target`` (float tensor): ``(N,d)``
 
     Args:
-        reduction: how to reduce over the batch dimension using 'sum', 'mean' or 'none'
-                    (taking the individual scores)
+        reduction: how to reduce over the batch dimension using 'sum', 'mean' or 'none' (taking the individual scores)
         compute_on_step:
-            Forward only calls ``update()`` and return ``None`` if this is set to ``False``.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-            default: ``None`` (which selects the entire world)
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When ``None``, DDP
-            will be used to perform the all gather.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example:
         >>> from torchmetrics import CosineSimilarity
@@ -68,18 +64,11 @@ class CosineSimilarity(Metric):
 
     def __init__(
         self,
-        reduction: str = "sum",
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        reduction: Literal["mean", "sum", "none", None] = "sum",
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         allowed_reduction = ("sum", "mean", "none", None)
         if reduction not in allowed_reduction:
             raise ValueError(f"Expected argument `reduction` to be one of {allowed_reduction} but got {reduction}")
