@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, Optional
+from typing import Any, Dict, Optional
 
 import torch
 from torch import Tensor, tensor
@@ -24,8 +24,7 @@ from torchmetrics.metric import Metric
 
 
 class MeanAbsolutePercentageError(Metric):
-    r"""
-    Computes `Mean Absolute Percentage Error`_ (MAPE):
+    r"""Computes `Mean Absolute Percentage Error`_ (MAPE):
 
     .. math:: \text{MAPE} = \frac{1}{n}\sum_{i=1}^n\frac{|   y_i - \hat{y_i} |}{\max(\epsilon, | y_i |)}
 
@@ -33,18 +32,18 @@ class MeanAbsolutePercentageError(Metric):
 
     Args:
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Note:
         The epsilon value is taken from `scikit-learn's implementation of MAPE`_.
 
     Note:
-        MAPE output is a non-negative floating point. Best result is 0.0 . But it is important to note that,
+        MAPE output is a non-negative floating point. Best result is ``0.0`` . But it is important to note that,
         bad predictions, can lead to arbitarily large values. Especially when some ``target`` values are close to 0.
         This `MAPE implementation returns`_ a very large number instead of ``inf``.
 
@@ -64,17 +63,10 @@ class MeanAbsolutePercentageError(Metric):
 
     def __init__(
         self,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
 
         self.add_state("sum_abs_per_error", default=tensor(0.0), dist_reduce_fx="sum")
         self.add_state("total", default=tensor(0.0), dist_reduce_fx="sum")
