@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from abc import ABC, abstractmethod
-from typing import Any, Callable, List, Optional
+from typing import Any, Dict, List, Optional
 
 import torch
 from torch import Tensor, tensor
@@ -33,10 +33,10 @@ class RetrievalMetric(Metric, ABC):
     - ``target`` (long or bool tensor): ``(N, ...)``
     - ``indexes`` (long tensor): ``(N, ...)``
 
-    `indexes`, `preds` and `target` must have the same dimension and will be flatten
+    ``indexes``, ``preds`` and ``target`` must have the same dimension and will be flatten
     to single dimension once provided.
 
-    `indexes` indicate to which query a prediction belongs.
+    ``indexes`` indicate to which query a prediction belongs.
     Predictions will be first grouped by indexes. Then the
     real metric, defined by overriding the `_metric` method,
     will be computed as the mean of the scores over each query.
@@ -54,15 +54,12 @@ class RetrievalMetric(Metric, ABC):
         ignore_index:
             Ignore predictions where the target is equal to this number.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When `None`, DDP
-            will be used to perform the allgather.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
@@ -80,17 +77,10 @@ class RetrievalMetric(Metric, ABC):
         self,
         empty_target_action: str = "neg",
         ignore_index: Optional[int] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         self.allow_non_binary_target = False
 
         empty_target_action_options = ("error", "skip", "neg", "pos")
