@@ -18,7 +18,7 @@
 # Link:
 
 import itertools
-from typing import Any, Callable, Dict, Iterator, List, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, Iterator, List, Optional, Sequence, Tuple, Union
 
 import torch
 from torch import Tensor, tensor
@@ -44,35 +44,27 @@ _DICT_STATES_TYPES = Tuple[
 
 
 class CHRFScore(Metric):
-    """Calculate `chrf score`_ of machine translated text with one or more references. This implementation supports
-    both ChrF score computation introduced in [1] and chrF++ score introduced in `chrF++ score_`. This
-    implementation follows the implmenetaions from https://github.com/m-popovic/chrF and
+    """Calculate `chrf score`_ of machine translated text with one or more references.
+
+    This implementation supports both ChrF score computation introduced in [1] and chrF++ score introduced
+    in `chrF++ score_`. This implementation follows the implmenetaions from https://github.com/m-popovic/chrF and
     https://github.com/mjpost/sacrebleu/blob/master/sacrebleu/metrics/chrf.py.
 
     Args:
-        n_char_order:
-            A character n-gram order. If `n_char_order=6`, the metrics refers to the official chrF/chrF++.
-        n_word_order:
-            A word n-gram order. If `n_word_order=2`, the metric refers to the official chrF++. If `n_word_order=0`, the
-            metric is equivalent to the original ChrF.
-        beta:
-            A parameter determining an importance of recall w.r.t. precision. If `beta=1`, their importance is equal.
-        lowercase:
-            An indication whether to enable case-insesitivity.
-        whitespace:
-            An indication whether keep whitespaces during n-gram extraction.
-        return_sentence_level_score:
-            An indication whether a sentence-level chrF/chrF++ score to be returned.
+        n_char_order: A character n-gram order. If ``n_char_order=6``, the metrics refers to the official chrF/chrF++.
+        n_word_order: A word n-gram order. If ``n_word_order=2``, the metric refers to the official chrF++.
+            If ``n_word_order=0``, the metric is equivalent to the original ChrF.
+        beta: parameter determining an importance of recall w.r.t. precision. If ``beta=1``, their importance is equal.
+        lowercase: An indication whether to enable case-insesitivity.
+        whitespace: An indication whether keep whitespaces during n-gram extraction.
+        return_sentence_level_score: An indication whether a sentence-level chrF/chrF++ score to be returned.
         compute_on_step:
             Forward only calls ``update()`` and returns None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When `None`, DDP
-            will be used to perform the allgather.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
@@ -92,6 +84,7 @@ class CHRFScore(Metric):
 
     References:
         [1] chrF: character n-gram F-score for automatic MT evaluation by Maja Popović `chrF score`_
+
         [2] chrF++: words helping character n-grams by Maja Popović `chrF++ score`_
     """
 
@@ -107,17 +100,10 @@ class CHRFScore(Metric):
         lowercase: bool = False,
         whitespace: bool = False,
         return_sentence_level_score: bool = False,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Optional[Callable] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ):
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
 
         if not isinstance(n_char_order, int) or n_char_order < 1:
             raise ValueError("Expected argument `n_char_order` to be an integer greater than or equal to 1.")
@@ -147,10 +133,8 @@ class CHRFScore(Metric):
         """Compute Precision Scores.
 
         Args:
-            preds:
-                An iterable of hypothesis corpus.
-            target:
-                An iterable of iterables of reference corpus.
+            preds: An iterable of hypothesis corpus.
+            target: An iterable of iterables of reference corpus.
         """
         n_grams_dicts_tuple = _chrf_score_update(
             preds,
